emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/mail/emacsbug.el,v


From: Michael Cadilhac
Subject: [Emacs-diffs] Changes to emacs/lisp/mail/emacsbug.el,v
Date: Fri, 17 Aug 2007 19:38:39 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Michael Cadilhac <cadilhac>     07/08/17 19:38:39

Index: emacsbug.el
===================================================================
RCS file: /sources/emacs/emacs/lisp/mail/emacsbug.el,v
retrieving revision 1.76
retrieving revision 1.77
diff -u -b -r1.76 -r1.77
--- emacsbug.el 17 Aug 2007 10:10:00 -0000      1.76
+++ emacsbug.el 17 Aug 2007 19:38:38 -0000      1.77
@@ -75,11 +75,16 @@
   (interactive (reverse (list (recent-keys) (read-string "Bug Subject: "))))
   ;; The syntax `version;' is preferred to `[version]' because the
   ;; latter could be mistakenly stripped by mailing software.
+  (if (eq system-type 'ms-dos)
+      (setq topic (concat emacs-version "; " topic))
   (when (string-match "^\\(\\([.0-9]+\\)*\\)\\.[0-9]+$" emacs-version)
-    (setq topic (concat (match-string 1 emacs-version) "; " topic)))
-  ;; If there are four numbers in emacs-version, this is a pretest
-  ;; version.
-  (let* ((pretest-p (string-match "\\..*\\..*\\." emacs-version))
+      (setq topic (concat (match-string 1 emacs-version) "; " topic))))
+  ;; If there are four numbers in emacs-version (three for MS-DOS),
+  ;; this is a pretest version.
+  (let* ((pretest-p (string-match (if (eq system-type 'ms-dos)
+                                     "\\..*\\."
+                                   "\\..*\\..*\\.")
+                                 emacs-version))
         (from-buffer (current-buffer))
         (reporting-address (if pretest-p
                                report-emacs-bug-pretest-address




reply via email to

[Prev in Thread] Current Thread [Next in Thread]